﻿Option Explicit On

Module Tools

    Public Structure TIniData
        Dim KeyName As String
        Dim KeyData As String
        Dim Selection As String
        Dim Comment As String
        Dim Unknown As String
    End Structure

    Public Enum TIniTypes
        Unknown = 0
        Selection = 1
        ValueName = 2
        Comment = 3
    End Enum

    Private Const m_Filter As String = "INI Files(*.ini)|*.ini|INF Files(*.inf)|*.inf|Config Files(*.cfg)|*.cfg|All Files(*.*)|*.*"
    Public Const Caption_Title As String = "Visual INI Editor"

    Private m_ButtonPress As DialogResult = DialogResult.Cancel
    Private m_Filename As String = vbNullString
    Private m_StrSource As String = vbNullString
    Public MyIniData As TIniData
    Public m_IniDataType As TIniTypes
    Private m_Edit As Boolean = False
    Private m_Comment As String = ";"

    Public Property StrLine As String
        Get
            Return m_StrSource
        End Get
        Set(ByVal value As String)
            m_StrSource = value
        End Set
    End Property

    Public Property Comment As String
        Get
            Return m_Comment
        End Get
        Set(ByVal value As String)
            m_Comment = value
        End Set
    End Property

    Public Property Editing As Boolean
        Get
            Return m_Edit
        End Get
        Set(ByVal value As Boolean)
            m_Edit = value
        End Set
    End Property

    Public Property Filename As String
        Get
            Return m_Filename
        End Get
        Set(ByVal value As String)
            m_Filename = value
        End Set
    End Property

    Public ReadOnly Property FileTypes As String
        Get
            Return m_Filter
        End Get
    End Property

    Public Property INIData As TIniTypes
        Get
            Return m_IniDataType
        End Get
        Set(ByVal value As TIniTypes)
            m_IniDataType = value
        End Set
    End Property

    Public Property ButtonPress As DialogResult
        Get
            Return m_ButtonPress
        End Get
        Set(ByVal value As DialogResult)
            m_ButtonPress = value
        End Set
    End Property

    Public Sub SetError(ByVal msg As String)
        MessageBox.Show(msg, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
    End Sub

    Public Function FixSelection(ByVal source As String) As String
        Dim sLine As String = source

        'Adiciona colchetes da seleção se preciso
        If Not sLine.StartsWith("[") Then
            sLine = "[" & sLine
        End If

        If Not sLine.EndsWith("]") Then
            sLine &= "]"
        End If

        'Retorna nova string
        Return sLine

    End Function

    Public Function FixComment(ByVal source As String) As String
        'Anexa um comentario a string se necessário
        If source.StartsWith(Comment) Then
            Return source
        End If
        Return Comment & " " & source
    End Function

    Public Function IsComment(ByVal source As String) As Boolean
        'verifica se temos um comentario
        Return source.StartsWith(Comment)
    End Function

    Public Function IsSelection(ByVal source As String) As Boolean
        'Retorna true se temo uma seleção
        Return source.StartsWith("[") And source.EndsWith("]")
    End Function

    Public Function GetSelectionName(ByVal source As String) As String
        Dim sLine As String = source

        'Remove os colchetes da seleção
        If sLine.StartsWith("[") Then
            sLine = sLine.Substring(1)
        End If

        If sLine.EndsWith("]") Then
            sLine = sLine.Substring(0, sLine.Length - 1)
        End If

        Return sLine

    End Function

    Public Function GetComment(ByVal source As String) As String

        If source.StartsWith(Comment) Then
            'Remove a tag de comentario e retorna os dados
            Return source.Substring(1).TrimStart()
        End If

        Return source
    End Function

    Public Function GetKeyName(ByVal source As String) As String
        Dim sPos As Integer = source.IndexOf("=")
        'Retorna o nome da chave
        If sPos <> -1 Then
            Return source.Substring(0, sPos)
        End If

        Return source
    End Function

    Public Function GetKeyData(ByVal source As String) As String
        Dim sPos As Integer = source.IndexOf("=")

        'Retorna o valor da chave
        If sPos <> -1 Then
            Return source.Substring(sPos + 1)
        End If

        Return source
    End Function

    Public Function Iskey(ByVal source As String) As Boolean
        Return source.IndexOf("=")<>-1
    End Function

    Public Sub MoveListItem(ByVal lb As ListBox, ByVal Up As Boolean)
        Dim Idx As Integer = 0
        Dim LItem As String = vbNullString
        Dim SelIdx As Integer = lb.SelectedIndex

        If Up Then
            Idx = (SelIdx - 1)
        Else
            Idx = (SelIdx + 1)
        End If

        If SelIdx.Equals(-1) Then
            Exit Sub
        End If

        'Pega o item texto
        LItem = lb.Items(SelIdx)

        If (Idx < 0) Then
            Exit Sub
        ElseIf (Idx >= lb.Items.Count) Then
            Exit Sub
        End If
        'Remove o item antigo
        lb.Items.RemoveAt(SelIdx)
        'Inseri um novo item
        lb.Items.Insert(Idx, LItem)
        'Seleciona um indice
        lb.SelectedIndex = Idx

    End Sub

    Public Sub RemoveAndSelectNext(ByVal lb As ListBox)
        Dim Del_Idx As Integer = lb.SelectedIndex
        'Remove o item e seleciona o proximo

        If (Del_Idx <> -1) Then
            'Item a remover
            lb.Items.RemoveAt(Del_Idx)
            'verifica se não esta fora do intervalo
            If (Del_Idx = lb.Items.Count) Then
                Del_Idx = (lb.Items.Count - 1)
            End If
            'Seleciona proximo item
            lb.SelectedIndex = Del_Idx
        End If
    End Sub
End Module
