﻿Option Explicit On
Imports System.IO

Public Class frmmain

    Private SelectIndex As Integer = -1
    Private m_FilterIndex As Integer = 1
    Private FileTitle As String = vbNullString
    Private OnOff As Boolean = False

    Private Sub AddListItem(ByVal Item As String)
        'Adiciona nova seleção
        If SelectIndex.Equals(-1) Then
            'Adicona novo item na lista
            LstItems.Items.Add(StrLine)
        Else
            'Insere novo item
            LstItems.Items.Insert(SelectIndex, StrLine)
        End If
        If LstItems.Items.Count = 1 Then
            'Seleciona o último indice
            LstItems.SelectedIndex = 0
        Else
            'Seleciona o ultimo indice
            LstItems.SelectedIndex = SelectIndex
        End If
    End Sub

    Private Function GetFilter(ByVal Filename As String) As Integer
        'Retorna o tipo de filtro
        Select Case New FileInfo(Filename).Extension.ToLower()
            Case ".ini"
                Return 1
            Case ".inf"
                Return 2
            Case ".cfg"
                Return 3
            Case Else
                Return 4
        End Select
    End Function

    Private Sub SetCaptionText(ByVal Filename As String)
        'define o titulo
        FileTitle = New FileInfo(Filename).Name
        Text = FileTitle & " - " & Caption_Title
    End Sub

    Private Sub SaveINI(ByVal Filename As String)
        Dim sw As StreamWriter
        Try
            sw = New StreamWriter(Filename)
            'Salva itens na listbox para o arquivo
            For x As Integer = 0 To LstItems.Items.Count - 1
                'escreve o arquivo
                sw.WriteLine(LstItems.Items(x))
            Next x
            'fecha o arquivo
            sw.Close()
        Catch ex As Exception
            SetError(ex.Message)
        End Try
        'limpa
        sw = Nothing
    End Sub

    Private Sub LoadINI(ByVal Filename As String)
        Dim sr As StreamReader
        'limpa listbox
        LstItems.Items.Clear()

        sr = New StreamReader(Filename)
        While sr.Peek <> -1
            Dim sLine As String = sr.ReadLine().Trim()
            'Adiciona linha no listbox
            LstItems.Items.Add(sLine)
        End While

        If (LstItems.Items.Count > 0) Then
            LstItems.SelectedIndex = 0
        End If
        'limpa
        sr.Close()
        sr = Nothing
    End Sub

    Private Sub cmdOpen_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdOpen.Click
        'abre o arquivo ini
        mnuOpen_Click(sender, e)
    End Sub

    Private Sub cmdSave_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdSave.Click
        'salva o arquivo ini
        mnuSaveAs_Click(sender, e)
    End Sub

    Private Sub cmdCut_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdCut.Click
        'Corta o texto
        mnuCut_Click(sender, e)
    End Sub

    Private Sub cmdCopy_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdCopy.Click
        'Copia o texto
        mnuCopy_Click(sender, e)
    End Sub

    Private Sub cmdPaste_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdPaste.Click
        'cola o texto
        mnuPaste_Click(sender, e)
    End Sub

    Private Sub LstItems_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles LstItems.SelectedIndexChanged
        SelectIndex = LstItems.SelectedIndex

        If (SelectIndex <> -1) Then
            If IsComment(LstItems.Items(SelectIndex)) Then
                cmdComment.Image = PicOn.Image
            Else
                cmdComment.Image = PicOff.Image
            End If
        End If

    End Sub

    Private Sub mnuExit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuExit.Click
        'sai do programa
        Close()
    End Sub

    Private Sub mnuOpen_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuOpen.Click
        Dim od As New OpenFileDialog()

        With od
            .Title = "Abrir"
            .Filter = FileTypes
            .FileName = FileTitle
            .FilterIndex = m_FilterIndex

            If .ShowDialog().Equals(DialogResult.OK) Then
                m_FilterIndex = GetFilter(.FileName)

                SetCaptionText(.FileName)
                'carrega o arquivo na listbox.
                LoadINI(.FileName)
            End If
        End With
    End Sub

    Private Sub mnuSaveAs_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuSaveAs.Click
        Dim sd As New SaveFileDialog()

        With sd
            .Title = "Salvar Como"
            .Filter = FileTypes
            .FileName = FileTitle
            .FilterIndex = m_FilterIndex

            If .ShowDialog().Equals(DialogResult.OK) Then
                m_FilterIndex = GetFilter(.FileName)
                SetCaptionText(.FileName)
                'salva o conteudo da listbox no arquivo
                SaveINI(.FileName)
            End If
        End With
    End Sub

    Private Sub mnuSelection_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuSelection.Click
        Dim frm As New frmSelection()
        Editing = False
        frm.ShowDialog()
        If ButtonPress.Equals(DialogResult.OK) Then
            AddListItem(StrLine)
        End If

        ButtonPress = DialogResult.Cancel

    End Sub

    Private Sub mnuComment_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuComment.Click
        Dim frm As New frmComment()
        Editing = False
        frm.ShowDialog()
        If ButtonPress.Equals(DialogResult.OK) Then
            AddListItem(StrLine)
        End If

        ButtonPress = DialogResult.Cancel
    End Sub

    Private Sub mnuKey_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuKey.Click
        Dim frm As New frmKey()
        Editing = False
        frm.ShowDialog()
        'verifica o botão pressionado
        If ButtonPress.Equals(DialogResult.OK) Then
            'Adiciona chave e valor
            AddListItem(StrLine)
        End If

        'Reseta botão pressionado
        ButtonPress = DialogResult.Cancel
    End Sub

    Private Sub frmmain_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Dim sCmd As String = Command().Replace(ControlChars.Quote, vbNullString)

        Text = "Sem Título - " & Caption_Title
        mnuAbout.Text = "&Sobre " & Caption_Title
        'define imagem
        cmdComment.Image = PicOff.Image

        'abre arquivo ini
        If (sCmd.Length > 0) Then
            LoadINI(sCmd)
            'define titulo
            SetCaptionText(sCmd)
            m_FilterIndex = GetFilter(sCmd)
        End If
    End Sub

    Private Sub cmdEdit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdEdit.Click
        Dim dType As TIniTypes = TIniTypes.Unknown
        Dim frmCom As New frmComment()
        Dim frmSel As New frmSelection()
        Dim frmVal As New frmKey()
        Dim frmEdit As New frmEditLine()

        If (SelectIndex <> -1) Then
            Dim sLine As String = LstItems.Items(SelectIndex)
            Editing = True

            'verifica qual tipo de linha
            If IsComment(sLine) Then
                dType = TIniTypes.Comment
            ElseIf IsSelection(sLine) Then
                dType = TIniTypes.Selection
            ElseIf Iskey(sLine) Then
                dType = TIniTypes.ValueName
            Else
                dType = TIniTypes.Unknown
            End If

            Select Case dType
                Case TIniTypes.Comment
                    'armazena comentario
                    MyIniData.Comment = GetComment(sLine)
                    frmCom.ShowDialog()
                Case TIniTypes.Selection
                    'armazena o nome selecionado
                    MyIniData.Selection = GetSelectionName(sLine)
                    frmSel.ShowDialog()
                Case TIniTypes.ValueName
                    'armazena o nome da chave e o valor 
                    MyIniData.KeyName = GetKeyName(sLine)
                    MyIniData.KeyData = GetKeyData(sLine)
                    frmKey.ShowDialog()
                Case TIniTypes.Unknown
                    'Armazena o conteudo da linha
                    MyIniData.Unknown = sLine
                    frmEdit.ShowDialog()
            End Select

            If ButtonPress.Equals(DialogResult.OK) Then
                'Atualiza a lista
                LstItems.Items(SelectIndex) = StrLine
            End If

            'Reseta o botão pressionado
            ButtonPress = DialogResult.OK
        End If
    End Sub

    Private Sub mnuCut_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuCut.Click
        If (LstItems.Items.Count > 0) Then
            'Copia item para o clipboard.
            Try
                Clipboard.SetText(LstItems.Items(SelectIndex), TextDataFormat.Text)
            Catch ex As Exception

            End Try
            'Remove item selecionado
            RemoveAndSelectNext(LstItems)
        End If
    End Sub

    Private Sub mnuCopy_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuCopy.Click
        'Copia linha selecionada para oclipboard.
        Try
            Clipboard.SetText(LstItems.Items(SelectIndex), TextDataFormat.Text)
        Catch ex As Exception

        End Try
    End Sub

    Private Sub mnuPaste_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuPaste.Click
        'Insere texto na posição
        Dim Item As String = Clipboard.GetText()

        If (Item.Length > 0) Then
            If SelectIndex.Equals(-1) Then
                'Adiciona nova item
                LstItems.Items.Add(Item)
            Else
                'Insere item no local selecionado
                LstItems.Items.Insert(SelectIndex, Item)
                LstItems.SelectedIndex = SelectIndex
            End If
        End If
    End Sub

    Private Sub mnuAbout_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuAbout.Click
        Dim frm As New frmAbout()
        frm.ShowDialog()
    End Sub

    Private Sub LstItems_MouseDoubleClick(ByVal sender As System.Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles LstItems.MouseDoubleClick
        If e.Button.Equals(MouseButtons.Left) Then
            'dispara o evento cmdEdit_Click
            cmdEdit_Click(sender, e)
        End If
    End Sub

    Private Sub mnuBlankFile_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuBlankFile.Click
        'Reseta o nome do arquivo
        m_FilterIndex = 1
        FileTitle = vbNullString
        Text = "Sem Título - " & Caption_Title
        'limpa listbox
        LstItems.Items.Clear()
    End Sub

    Private Sub MnuAutoRun1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MnuAutoRun1.Click
        'Reseta o noe do arquivo
        m_FilterIndex = 2
        FileTitle = vbNullString
        Text = "Sem Título - " & Caption_Title
        'limpa listbox
        LstItems.Items.Clear()
        LstItems.Items.Add("[AutoRun]")
        LstItems.Items.Add("OPEN=YourProgram.exe")
        LstItems.Items.Add("ICON=PathToIcon.ico")
        LstItems.Items.Add("LABEL=YourLabel")
        LstItems.SelectedIndex = 0
    End Sub

    Private Sub mnuBlank_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuBlank.Click
        'Novo arquivo em branco
        mnuBlankFile_Click(sender, e)
    End Sub

    Private Sub mnuAutoRun_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuAutoRun.Click
        'novo arquivo 
        MnuAutoRun1_Click(sender, e)
    End Sub

    Private Sub mnuBlankLine_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuBlankLine.Click
        'Adiciona nova seleção
        StrLine = vbCrLf
        AddListItem(StrLine)
    End Sub

    Private Sub cmdHelp_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdHelp.Click
        'mostra caixa sobre
        mnuAbout_Click(sender, e)
    End Sub

    Private Sub cmdUp_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdUp.Click
        'Move item para cima
        MoveListItem(LstItems, True)
    End Sub

    Private Sub cmdDown_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdDown.Click
        'Move o item para baixo
        MoveListItem(LstItems, False)
    End Sub

    Private Sub cmdComment_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdComment.Click
        Dim Buff As String = vbNullString

        If SelectIndex.Equals(-1) Then
            Exit Sub
        Else
            'Pega  a linha atual
            Dim sLine As String = LstItems.Items(SelectIndex)

            If IsComment(sLine) Then
                'define a imagem
                cmdComment.Image = PicOff.Image
                'pega o conteudo dos comentarios
                Buff = GetComment(sLine)
                'Remove o comentario
                LstItems.Items(SelectIndex) = Buff
            Else
                Buff = GetComment(sLine)
                'Anexa uma linha de comentario
                LstItems.Items(SelectIndex) = FixComment(Buff)
                'define o botao da imagem
                cmdComment.Image = PicOn.Image
            End If
        End If

    End Sub
End Class
